@@ -277,6 +277,22 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
 	*svp  &&  SvTRUE(*svp)) {
         unixSocket = SvPV(*svp, na);
     }
+#elif defined(IDX_TYPE)
+    if ((svp = hv_fetch(hv, "msql_configfile", 15, FALSE))  &&
+	*svp  &&  SvOK(*svp)) {
+        char* cf = SvPV(*svp, na);
+	if (dbis->debug >= 2) {
+	    fprintf(DBILOGFP, "imp_dbh->MyLogin: Loading config file %s\n",
+		    cf);
+	}
+	if (msqlLoadConfigFile(cf) == -1) {
+	    croak("Failed to load config file %s", cf);
+	}
+    }
+    if (port != 0) {
+        warn("Port settings are meaningless with mSQL 2." \
+	     " Use msql_configfile instead.\n");
+    }
 #endif
 
     if (dbis->debug >= 2)
@@ -825,6 +841,7 @@ int dbd_st_internal_execute(SV* h, SV* statement, SV* attribs, int numParams,
 	if (salloc) printf("Freeing ParseParam: %08x\n", (unsigned int) salloc);
 #endif
         Safefree(salloc);
+
 	DO_ERROR(h, JW_ERR_QUERY, svsock);
 	return -2;
     }
@@ -1709,4 +1726,11 @@ int MysqlReconnect(SV* h) {
     return TRUE;
 }
 
+#if !defined(_UNIX_)  &&  defined(WIN32)
+int pthread_cond_init()
+{
+  return 0;
+}
+#endif
+
 #endif
